@@ -29,7 +29,7 @@ else:
 locale.setlocale(locale.LC_ALL, '')
 
 
-def get_diskinfo(outunit, show_all=False, debug=False):
+def get_diskinfo(outunit, show_all=False, debug=False, local_only=False):
     ''' Returns a list holding the current disk info,
         stats divided by the ouptut unit.
     '''
@@ -61,7 +61,9 @@ def get_diskinfo(outunit, show_all=False, debug=False):
                 disk.pcnt   = int(tokens[4][:-1])
                 disk.used   = float(tokens[2]) * 1024 / outunit
                 disk.ismntd = True
-                disk.isnet  = None
+                disk.isnet  = ':' in tokens[0]  # cheesy but works
+                if local_only and disk.isnet:
+                    continue
                 disk.isopt  = None
                 disk.isrem  = None
                 disk.rw     = True
@@ -71,8 +73,8 @@ def get_diskinfo(outunit, show_all=False, debug=False):
         return None
 
     if debug:  print disks
-    keys = sorted(disks.keys())
-    return [ disks[dev]  for dev in keys ]
+    devices = sorted(disks.keys())
+    return [ disks[device]  for device in devices ]
 
 
 def get_meminfo(outunit, debug=False):
