@@ -57,7 +57,7 @@ _drive_type_result = {
 }
 
 
-def get_diskinfo(outunit, show_all=False, debug=False):
+def get_diskinfo(outunit, show_all=False, debug=False, local_only=False):
     ''' Returns a list holding the current disk info,
         stats divided by the ouptut unit.
     '''
